@@ -6,13 +6,17 @@ use warnings FATAL => 'all';
 
 use ojo;
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 sub import {
     push @{app->static->paths}, app->home->rel_file('.');
     app->start('daemon');
 }
 
+1;
+
+__END__
+
 =head1 NAME
 
 ojo::ServeDir - Helper module to serve local files
@@ -25,6 +29,14 @@ Version 0.01
 
     $ perl -Mojo::ServeDir
 
+=head1 CONTRIBUTORS
+
+=over 4
+
+=item Mohammad S Anwar
+
+=back
+
 =head1 AUTHOR
 
 Mirko Westermeier, C<< <mirko at westermeier.de> >>
@@ -34,7 +46,3 @@ Mirko Westermeier, C<< <mirko at westermeier.de> >>
 This software is Copyright (c) 2019 by Mirko Westermeier.
 
 Released under the MIT (X11) license. See LICENSE for details.
-
-=cut
-
-1; # End of ojo::ServeDir
